<?php
/**
 * Counter Section options
 *
 * @package Theme Palace
 * @subpackage Trade More
 * @since Trade More 1.0.0
 */

// Add Counter section
$wp_customize->add_section( 'fondness_counter_section', array(
	'title'             => esc_html__( 'Counter','trade-more' ),
	'description'       => esc_html__( 'Counter Section options.', 'trade-more' ),
	'panel'             => 'fondness_front_page_panel',
	'priority'			=> 25,
) );

// Counter content enable control and setting
$wp_customize->add_setting( 'counter_section_enable', array(
	'default'			=> 	false,
	'sanitize_callback' => 'fondness_sanitize_switch_control',
) );

$wp_customize->add_control( new Trade_More_Switch_Control( $wp_customize, 'counter_section_enable', array(
	'label'             => esc_html__( 'Counter Section Enable', 'trade-more' ),
	'section'           => 'fondness_counter_section',
	'on_off_label' 		=> fondness_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'counter_section_enable', array(
		'selector'            => '#counter-section .tooltiptext',
		'settings'            => 'counter_section_enable',
    ) );
}

// counter image setting and control.
$wp_customize->add_setting( 'counter_image', array(
	'sanitize_callback' => 'fondness_sanitize_image'
) );

$wp_customize->add_control( new WP_Customize_Image_Control( $wp_customize, 'counter_image',
		array(
		'label'       		=> esc_html__( 'Counter BG Image', 'trade-more' ),
		'section'     		=> 'fondness_counter_section',
		'active_callback'	=> 'trade_more_is_counter_section_enable',
) ) );

for ( $i = 1; $i <= 4; $i++ ) :

	// service note control and setting
	$wp_customize->add_setting( 'counter_icon_' . $i, array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

$wp_customize->add_control( new Trade_More_Icon_Picker( $wp_customize, 'counter_icon_' . $i, array(
	'label'             => sprintf( esc_html__( 'Select Icon %d', 'trade-more' ), $i ),
	'section'           => 'fondness_counter_section',
	'active_callback'	=> 'trade_more_is_counter_section_enable',
	) ) );
	
	// counter title setting and control
	$wp_customize->add_setting( 'counter_value_' . $i, array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'counter_value_' . $i, array(
		'label'           	=> sprintf( esc_html__( 'Value %d', 'trade-more' ), $i ),
		'section'        	=> 'fondness_counter_section',
		'active_callback' 	=> 'trade_more_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter position setting and control
	$wp_customize->add_setting( 'counter_label_' . $i, array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'counter_label_' . $i, array(
		'label'           	=> sprintf( esc_html__( 'Label %d', 'trade-more' ), $i ),
		'section'        	=> 'fondness_counter_section',
		'active_callback' 	=> 'trade_more_is_counter_section_enable',
		'type'				=> 'text',
	) );

	// counter hr setting and control
	$wp_customize->add_setting( 'counter_hr_'. $i, array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Trade_More_Customize_Horizontal_Line( $wp_customize, 'counter_hr_'. $i,
		array(
			'section'         => 'fondness_counter_section',
			'active_callback' => 'trade_more_is_counter_section_enable',
			'type'			  => 'hr'
	) ) );

endfor;