<?php
/**
* Service Section options
*
* @package Theme Palace
* @subpackage Fondness Pro
* @since Fondness Pro 1.0.0
*/

// Add Service section
$wp_customize->add_section( 'fondness_service_section', array(
	'title'             => esc_html__( 'Services','trade-more' ),
	'description'       => esc_html__( 'Services Section options.', 'trade-more' ),
	'panel'             => 'fondness_front_page_panel',
	'priority'			=> 45,
) );

// Service content enable control and setting
$wp_customize->add_setting( 'service_section_enable', array(
	'default'			=> 	false,
	'sanitize_callback' => 'fondness_sanitize_switch_control',
	) );

$wp_customize->add_control( new Trade_More_Switch_Control( $wp_customize, 'service_section_enable', array(
	'label'             => esc_html__( 'Service Section Enable', 'trade-more' ),
	'section'           => 'fondness_service_section',
	'on_off_label' 		=> fondness_switch_options(),
	) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'service_section_enable', array(
		'selector'            => '#our-services .tooltiptext',
		'settings'            => 'service_section_enable',
		) );
}

// service title setting and control
	$wp_customize->add_setting( 'service_sub_title',
		array(
			'default'       		=> esc_html__( 'SERVICES', 'trade-more' ),
			'sanitize_callback'		=> 'sanitize_text_field',
			'transport'				=> 'postMessage',
			)
		);
	$wp_customize->add_control( 'service_sub_title',
		array(
			'label'      			=> esc_html__( 'Section Sub Title', 'trade-more' ),
			'section'    			=> 'fondness_service_section',
			'type'		 			=> 'text',
			'active_callback'		=> 'trade_more_is_service_section_enable',
			)
		);

// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'service_sub_title', array(
			'selector'            => '#our-services h3.section-subtitle',
			'settings'            => 'service_sub_title',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'trade_more_service_sub_title_partial',
			) );
	}

// service title setting and control
	$wp_customize->add_setting( 'service_title',
		array(
			'default'       		=> esc_html__( 'WHAT WE DO', 'trade-more' ),
			'sanitize_callback'		=> 'sanitize_text_field',
			'transport'				=> 'postMessage',
			)
		);
	$wp_customize->add_control( 'service_title',
		array(
			'label'      			=> esc_html__( 'Section Title', 'trade-more' ),
			'section'    			=> 'fondness_service_section',
			'type'		 			=> 'text',
			'active_callback'		=> 'trade_more_is_service_section_enable',
			)
		);

// Abort if selective refresh is not available.
	if ( isset( $wp_customize->selective_refresh ) ) {
		$wp_customize->selective_refresh->add_partial( 'service_title', array(
			'selector'            => '#our-services h2.section-title',
			'settings'            => 'service_title',
			'container_inclusive' => false,
			'fallback_refresh'    => true,
			'render_callback'     => 'trade_more_service_title_partial',
			) );
	}

for ( $i = 1; $i <= 6; $i++ ) :

// service note control and setting
	$wp_customize->add_setting( 'service_content_icon_' . $i, array(
		'sanitize_callback' => 'sanitize_text_field',
		) );

$wp_customize->add_control( new Trade_More_Icon_Picker( $wp_customize, 'service_content_icon_' . $i, array(
	'label'             => sprintf( esc_html__( 'Select Icon %d', 'trade-more' ), $i ),
	'section'           => 'fondness_service_section',
	'active_callback'	=> 'trade_more_is_service_section_enable',
	) ) );

// service pages drop down chooser control and setting
$wp_customize->add_setting( 'service_content_page_' . $i, array(
	'sanitize_callback' => 'fondness_sanitize_page',
	) );

$wp_customize->add_control( new Trade_More_Dropdown_Chooser( $wp_customize, 'service_content_page_' . $i, array(
	'label'             => sprintf( esc_html__( 'Select Page %d', 'trade-more' ), $i ),
	'section'           => 'fondness_service_section',
	'choices'			=> fondness_page_choices(),
	'active_callback'	=> 'trade_more_is_service_section_enable',
	) ) );

endfor;