<?php
/**
 * Testimonial Section options
 *
 * @package Theme Palace
 * @subpackage Trade More
 * @since Trade More 1.0.0
 */

// Add Testimonial section
$wp_customize->add_section( 'fondness_testimonial_section', array(
	'title'             => esc_html__( 'Testimonial','trade-more' ),
	'description'       => esc_html__( 'Testimonial Section options.', 'trade-more' ),
	'panel'             => 'fondness_front_page_panel',
	'priority'			=> 46,
) );

// Testimonial content enable control and setting
$wp_customize->add_setting( 'testimonial_section_enable', array(
	'default'			=> 	false,
	'sanitize_callback' => 'fondness_sanitize_switch_control',
) );

$wp_customize->add_control( new Trade_More_Switch_Control( $wp_customize, 'testimonial_section_enable', array(
	'label'             => esc_html__( 'Testimonial Section Enable', 'trade-more' ),
	'section'           => 'fondness_testimonial_section',
	'on_off_label' 		=> fondness_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'testimonial_section_enable', array(
		'selector'            => '#testimonial-section .tooltiptext',
		'settings'            => 'testimonial_section_enable',
    ) );
}

for ( $i = 1; $i <= 3; $i++ ) :
	// testimonial pages drop down chooser control and setting
	$wp_customize->add_setting( 'testimonial_content_page_' . $i, array(
		'sanitize_callback' => 'fondness_sanitize_page',
	) );

	$wp_customize->add_control( new Trade_More_Dropdown_Chooser( $wp_customize, 'testimonial_content_page_' . $i, array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'trade-more' ), $i ),
		'section'           => 'fondness_testimonial_section',
		'choices'			=> fondness_page_choices(),
		'active_callback'	=> 'trade_more_is_testimonial_section_enable',
	) ) );

	$wp_customize->add_setting( 'testimonial_author_position_' . $i, array(
		'sanitize_callback' => 'sanitize_text_field',
	) );

	$wp_customize->add_control( 'testimonial_author_position_' . $i, array(
		'label'           	=> sprintf( esc_html__( 'Author Position %d', 'trade-more' ), $i ),
		'section'        	=> 'fondness_testimonial_section',
		'active_callback' 	=> 'trade_more_is_testimonial_section_enable',
		'type'				=> 'text',
	) );

	// testimonial hr setting and control
	$wp_customize->add_setting( 'testimonial_hr_'. $i, array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Trade_More_Customize_Horizontal_Line( $wp_customize, 'testimonial_hr_'. $i,
		array(
			'section'         => 'fondness_testimonial_section',
			'active_callback' => 'trade_more_is_testimonial_section_enable',
			'type'			  => 'hr'
	) ) );

endfor;